@@ -3,11 +3,10 @@
 # Include the wrappers utility script
 . /usr/lib/java-wrappers/java-wrappers.sh
 
-# We need a java5 runtime
-find_java_runtime java5
+find_java_runtime java8
 
 # Define our classpath
-find_jars bnd-1.50.0
+find_jars bnd
 
 # Run bnd
 run_java aQute.bnd.main.bnd $extra_args "$@"
